@@ -20,16 +20,16 @@ class Message:
                     component['disabled'] = True
 
         self.raw['components'] = self.components
-        await self.__socket.session.patch(f"https://discord.com/api/v8/channels/{self.channel_id}/messages/{self.id}", json=self.raw, headers=self.__socket.headers)
+        await self.__socket.make_request('PATCH', f"channels/{self.channel_id}/messages/{self.id}", json=self.raw)
         await self.__rebuild()
 
-    async def disable_all_Components(self):
+    async def disable_all_components(self):
         for action_row in self.components:
             for component in action_row['components']:
                 component['disabled'] = True
 
         self.raw['components'] = self.components
-        await self.__socket.session.patch(f"https://discord.com/api/v8/channels/{self.channel_id}/messages/{self.id}", json=self.raw, headers=self.__socket.headers)
+        await self.__socket.make_request('PATCH', f"channels/{self.channel_id}/messages/{self.id}", json=self.raw)
         await self.__rebuild()
 
     async def edit(self, content: str = '', embeds: list = [], components: list = [], mentions: list = []):
@@ -38,18 +38,24 @@ class Message:
         self.raw['components'] = components if len(components) != 0 else self.components
         self.raw['mentions'] = mentions if len(mentions) != 0 else self.raw['mentions']
         
-        await self.__socket.session.patch(f"https://discord.com/api/v8/channels/{self.channel_id}/messages/{self.id}", json=self.raw, headers=self.__socket.headers)
+        await self.__socket.make_request('PATCH', f"channels/{self.channel_id}/messages/{self.id}", json=self.raw)
         await self.__rebuild()
 
     async def delete(self):
-        await self.__socket.session.delete(f"https://discord.com/api/v8/channels/{self.channel_id}/messages/{self.id}", headers=self.__socket.headers)
+        await self.__socket.make_request('DELETE', f"channels/{self.channel_id}/messages/{self.id}")
 
-    async def fetch_reactions(self):
-        return 
+    async def fetch_reaction(self, reaction: str):
+        reactions = await self.__socket.make_request('GET', f"channels/{self.channel_id}/messages/{self.id}/reactions/{reaction}")
+        return reactions
+
+    async def add_reaction(self, reaction: str):
+        await self.__socket.make_request("PUT", f"channels/{self.channel_id}/messages/{self.id}/reactions/{reaction}/@me")
+
+        
 
     async def __rebuild(self):
-        message = await self.__socket.session.get(f"https://discord.com/api/v8/channels/{self.channel_id}/messages/{self.id}", headers=self.__socket.headers)
-        self.raw = await message.json()
+        message = await self.__socket.make_request('GET', f"channels/{self.channel_id}/messages/{self.id}")
+        self.raw = message
         self.__author = self.raw.get('author', None)
         if self.__author is not None:
             self.author = User(self.__author)
